aind\_behavior\_curriculum.curriculum.Curriculum
================================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: Curriculum
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Curriculum.__init__
      ~Curriculum.add_stage
      ~Curriculum.add_stage_transition
      ~Curriculum.construct
      ~Curriculum.copy
      ~Curriculum.default_pkg_location_factory
      ~Curriculum.dict
      ~Curriculum.from_orm
      ~Curriculum.json
      ~Curriculum.model_construct
      ~Curriculum.model_copy
      ~Curriculum.model_dump
      ~Curriculum.model_dump_json
      ~Curriculum.model_json_schema
      ~Curriculum.model_parametrized_name
      ~Curriculum.model_post_init
      ~Curriculum.model_rebuild
      ~Curriculum.model_validate
      ~Curriculum.model_validate_json
      ~Curriculum.model_validate_strings
      ~Curriculum.parse_file
      ~Curriculum.parse_obj
      ~Curriculum.parse_raw
      ~Curriculum.remove_stage
      ~Curriculum.remove_stage_transition
      ~Curriculum.schema
      ~Curriculum.schema_json
      ~Curriculum.see_stage_transitions
      ~Curriculum.see_stages
      ~Curriculum.set_stage_transition_priority
      ~Curriculum.task_discriminator_type
      ~Curriculum.update_forward_refs
      ~Curriculum.validate
      ~Curriculum.validate_curriculum
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Curriculum.model_computed_fields
      ~Curriculum.model_config
      ~Curriculum.model_extra
      ~Curriculum.model_fields
      ~Curriculum.model_fields_set
      ~Curriculum.pkg_location
      ~Curriculum.name
      ~Curriculum.version
      ~Curriculum.graph
   
   